@@ -1,4 +1,39 @@
-get_modeldata <- function(model, additional_variables = TRUE) {
+get_modeldata <- function(model, additional_variables = FALSE, modeldata = NULL, wts = NULL, ...) {
+
+    if (inherits(model, "mira")) {
+        return(modeldata)
+    }
+
+    if (!is.null(modeldata)) {
+        modeldata <- set_variable_class(modeldata, model = model)
+        return(modeldata)
+    }
+
+    # often used to extract `by`
+    if (isTRUE(checkmate::check_data_frame(additional_variables))) {
+        additional_variables <- colnames(additional_variables)
+    }
+
+    # always get weights
+    if (isTRUE(checkmate::check_string(wts))) {
+        additional_variables <- c(additional_variables, wts)
+    }
+
+    # feols weights can be a formula
+    if (inherits(model, "fixest")) {
+        fwts <- tryCatch(all.vars(model$call$weights), error = function(e) NULL)
+        additional_variables <- c(additional_variables, fwts)
+    }
+
+    # after by
+    if (isTRUE(checkmate::check_flag(additional_variables))) {
+        out <- hush(insight::get_data(
+            model, additional_variables = additional_variables, verbose = FALSE)
+        )
+        out <- set_variable_class(out, model = model)
+        return(out)
+    }
+
     # always extract offset variable if available
     off <- hush(insight::find_offset(model))
     if (isTRUE(checkmate::check_formula(off))) {
@@ -10,19 +45,37 @@ get_modeldata <- function(model, additional_variables = TRUE) {
             additional_variables <- c(additional_variables, off)
         }
     }
+
+    # always extract weights variable if available
+    wts <- hush(insight::find_weights(model))
+    if (isTRUE(checkmate::check_formula(wts))) {
+        additional_variables <- c(additional_variables, hush(all.vars(wts)))
+    } else if (isTRUE(checkmate::check_character(wts, max.len = 4))) {
+        if (isTRUE(grepl("~", wts))) {
+            additional_variables <- c(additional_variables, hush(all.vars(stats::as.formula(wts))))
+        } else {
+            additional_variables <- c(additional_variables, wts)
+        }
+    }
+
+
     out <- hush(insight::get_data(model, verbose = FALSE, additional_variables = additional_variables))
+
     # iv_robust and some others
     if (is.null(out)) {
         out <- evalup(model[["call"]][["data"]])
     }
+
     if (is.null(out)) {
         out <- evalup(attr(model, "call")$data)
     }
+
     out <- as.data.frame(out)
-    out <- set_variable_class(modeldata = out, model = model)
+    out <- set_variable_class(out, model = model)
     return(out)
 }
 
+
 set_variable_class <- function(modeldata, model = NULL) {
 
     if (is.null(modeldata)) return(modeldata)
