@@ -5,6 +5,11 @@ EXPENSIVE <- FALSE
 
 options("tinysnapshot_device" = "svglite")
 options("tinysnapshot_tol" = 200)
+options(marginaleffects_numDeriv = NULL)
+
+if (isTRUE(insight::check_if_installed("cmdstanr", quietly = TRUE))) {
+    options("brms.backend" = "cmdstanr")
+}
 
 # libraries
 requiet <- function(package) {
