@@ -1,17 +1,18 @@
 source("helpers.R")
+exit_file("Matrix")
 using("marginaleffects")
 
-exit_if_not(requiet("polspline"))
-exit_if_not(requiet("rms"))
-exit_if_not(requiet("emmeans"))
-exit_if_not(requiet("broom"))
+requiet("polspline")
+requiet("rms")
+requiet("emmeans")
+requiet("broom")
 
 # lmr: marginaleffects vs emtrends
 model <- rms::lrm(am ~ mpg, mtcars)
 void <- capture.output({
     expect_slopes(model, type = "lp", n_unique = 1)
 })
-mfx <- slopes(model, newdata = data.frame(mpg = 30), type = "lp")
+mfx <- slopes(model, newdata = data.frame(mpg = 30), type = "lp", eps = 1/1000 * diff(range(mtcars$mpg)))
 em <- emtrends(model, ~mpg, "mpg", at = list(mpg = 30))
 em <- tidy(em)
 expect_equivalent(mfx$estimate, em$mpg.trend)
