@@ -1,7 +1,7 @@
 source("helpers.R")
 using("marginaleffects")
 
-exit_if_not(requiet("sandwich"))
+requiet("sandwich")
 
 
 dat <- read.csv("https://vincentarelbundock.github.io/Rdatasets/csv/datasets/mtcars.csv")
@@ -119,3 +119,6 @@ expect_equivalent(x, y)
 x <- slopes(mod, vcov = sandwich::vcovHC)
 y <- slopes(mod, vcov = "HC3")
 expect_equivalent(x, y)
+
+
+rm(list = ls())
